@@ -54,6 +54,7 @@ class AutoMLAlgorithm(ABC):
             )
         self._pipeline_number = 0
         self._batch_number = 0
+        self._default_max_batches = 1
 
     @abstractmethod
     def next_batch(self):
@@ -99,6 +100,11 @@ class AutoMLAlgorithm(ABC):
         """Returns the number of batches which have been recommended so far."""
         return self._batch_number
 
+    @property
+    def default_max_batches(self):
+        """Returns the number of max batches AutoMLSearch should run by default."""
+        return 1
+
     def _create_ensemble(self):
         next_batch = []
         best_pipelines = list(self._best_pipeline_info.values())
