@@ -1,5 +1,5 @@
 import warnings
-from unittest.mock import MagicMock, patch
+from unittest.mock import patch
 
 import numpy as np
 import pandas as pd
@@ -10,9 +10,7 @@ from evalml import AutoMLSearch
 from evalml.automl.automl_algorithm import DefaultAlgorithm, IterativeAlgorithm
 from evalml.automl.callbacks import raise_error_callback
 from evalml.automl.pipeline_search_plots import SearchIterationPlot
-from evalml.automl.utils import get_best_sampler_for_data
 from evalml.exceptions import ParameterNotUsedWarning, PipelineNotFoundError
-from evalml.model_family import ModelFamily
 from evalml.objectives import (
     FraudCost,
     Precision,
@@ -22,14 +20,11 @@ from evalml.objectives import (
     get_objective,
 )
 from evalml.pipelines import (
-    BinaryClassificationPipeline,
-    MulticlassClassificationPipeline,
     PipelineBase,
     TimeSeriesBinaryClassificationPipeline,
     TimeSeriesMulticlassClassificationPipeline,
 )
 from evalml.pipelines.components.utils import get_estimators
-from evalml.pipelines.utils import make_pipeline
 from evalml.preprocessing import TimeSeriesSplit, split_data
 from evalml.problem_types import ProblemTypes
 
@@ -43,7 +38,7 @@ def test_init(X_y_binary):
     automl.search()
 
     assert automl.n_jobs == 1
-    assert isinstance(automl._automl_algorithm, IterativeAlgorithm)
+    assert isinstance(automl.automl_algorithm, DefaultAlgorithm)
     assert isinstance(automl.rankings, pd.DataFrame)
     assert isinstance(automl.best_pipeline, PipelineBase)
     automl.best_pipeline.predict(X)
@@ -67,9 +62,9 @@ def test_init(X_y_binary):
         problem_type="binary",
         max_iterations=1,
         n_jobs=1,
-        _automl_algorithm="default",
+        automl_algorithm="iterative",
     )
-    assert isinstance(automl._automl_algorithm, DefaultAlgorithm)
+    assert isinstance(automl.automl_algorithm, IterativeAlgorithm)
 
     with pytest.raises(ValueError, match="Please specify a valid automl algorithm."):
         AutoMLSearch(
@@ -78,7 +73,7 @@ def test_init(X_y_binary):
             problem_type="binary",
             max_iterations=1,
             n_jobs=1,
-            _automl_algorithm="not_valid",
+            automl_algorithm="not_valid",
         )
 
 
@@ -284,7 +279,6 @@ def test_random_seed(X_y_binary):
         y_train=y,
         problem_type="binary",
         objective=Precision(),
-        max_batches=1,
         random_seed=0,
         n_jobs=1,
     )
@@ -326,6 +320,7 @@ def test_callback(X_y_binary):
         start_iteration_callback=start_iteration_callback,
         add_result_callback=add_result_callback,
         n_jobs=1,
+        automl_algorithm="iterative",
     )
     automl.search()
 
@@ -710,371 +705,6 @@ def test_max_time(X_y_binary):
     assert len(automl.results["pipeline_results"]) == 1
 
 
-@pytest.mark.parametrize("automl_type", [ProblemTypes.BINARY, ProblemTypes.MULTICLASS])
-def test_automl_allowed_component_graphs_no_component_graphs(
-    automl_type, X_y_binary, X_y_multi
-):
-    is_multiclass = automl_type == ProblemTypes.MULTICLASS
-    X, y = X_y_multi if is_multiclass else X_y_binary
-    problem_type = "multiclass" if is_multiclass else "binary"
-    with pytest.raises(ValueError, match="No allowed pipelines to search"):
-        AutoMLSearch(
-            X_train=X,
-            y_train=y,
-            problem_type=problem_type,
-            allowed_component_graphs=None,
-            allowed_model_families=[],
-        )
-
-
-def test_automl_component_graphs_specified_component_graphs_binary(
-    AutoMLTestEnv,
-    dummy_classifier_estimator_class,
-    dummy_binary_pipeline,
-    X_y_binary,
-):
-    X, y = X_y_binary
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="binary",
-        allowed_component_graphs={
-            "Mock Binary Classification Pipeline": [dummy_classifier_estimator_class]
-        },
-        optimize_thresholds=False,
-        allowed_model_families=None,
-    )
-    expected_component_graph = dummy_binary_pipeline.component_graph
-    expected_name = dummy_binary_pipeline.name
-    expected_parameters = dummy_binary_pipeline.parameters
-    assert automl.allowed_pipelines[0].component_graph == expected_component_graph
-    assert automl.allowed_pipelines[0].name == expected_name
-    assert automl.allowed_pipelines[0].parameters == expected_parameters
-    assert automl.allowed_model_families == [ModelFamily.NONE]
-
-    env = AutoMLTestEnv("binary")
-    with env.test_context(score_return_value={automl.objective.name: 1.0}):
-        automl.search()
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-    assert automl.allowed_pipelines[0].component_graph == expected_component_graph
-    assert automl.allowed_pipelines[0].name == expected_name
-    assert automl.allowed_pipelines[0].parameters == expected_parameters
-    assert automl.allowed_model_families == [ModelFamily.NONE]
-
-
-def test_automl_component_graphs_specified_component_graphs_multi(
-    AutoMLTestEnv,
-    dummy_classifier_estimator_class,
-    dummy_multiclass_pipeline,
-    X_y_multi,
-):
-    X, y = X_y_multi
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="multiclass",
-        allowed_component_graphs={
-            "Mock Multiclass Classification Pipeline": [
-                dummy_classifier_estimator_class
-            ]
-        },
-        allowed_model_families=None,
-    )
-    expected_pipeline = dummy_multiclass_pipeline
-    expected_component_graph = expected_pipeline.component_graph
-    expected_name = expected_pipeline.name
-    expected_parameters = expected_pipeline.parameters
-    assert automl.allowed_pipelines[0].component_graph == expected_component_graph
-    assert automl.allowed_pipelines[0].name == expected_name
-    assert automl.allowed_pipelines[0].parameters == expected_parameters
-    assert automl.allowed_model_families == [ModelFamily.NONE]
-
-    env = AutoMLTestEnv("multiclass")
-    with env.test_context(score_return_value={automl.objective.name: 1.0}):
-        automl.search()
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-    assert automl.allowed_pipelines[0].component_graph == expected_component_graph
-    assert automl.allowed_pipelines[0].name == expected_name
-    assert automl.allowed_pipelines[0].parameters == expected_parameters
-    assert automl.allowed_model_families == [ModelFamily.NONE]
-
-
-def test_automl_component_graphs_specified_allowed_model_families_binary(
-    AutoMLTestEnv, X_y_binary, assert_allowed_pipelines_equal_helper
-):
-    X, y = X_y_binary
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="binary",
-        allowed_component_graphs=None,
-        allowed_model_families=[ModelFamily.RANDOM_FOREST],
-        optimize_thresholds=False,
-    )
-    expected_pipelines = [
-        make_pipeline(X, y, estimator, ProblemTypes.BINARY)
-        for estimator in get_estimators(
-            ProblemTypes.BINARY, model_families=[ModelFamily.RANDOM_FOREST]
-        )
-    ]
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-
-    env = AutoMLTestEnv("binary")
-    with env.test_context(score_return_value={automl.objective.name: 1.0}):
-        automl.search()
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="binary",
-        allowed_component_graphs=None,
-        allowed_model_families=["random_forest"],
-        optimize_thresholds=False,
-    )
-    expected_pipelines = [
-        make_pipeline(X, y, estimator, ProblemTypes.BINARY)
-        for estimator in get_estimators(
-            ProblemTypes.BINARY, model_families=[ModelFamily.RANDOM_FOREST]
-        )
-    ]
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    with env.test_context(score_return_value={automl.objective.name: 1.0}):
-        automl.search()
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-
-def test_automl_component_graphs_specified_allowed_model_families_multi(
-    AutoMLTestEnv, X_y_multi, assert_allowed_pipelines_equal_helper
-):
-    X, y = X_y_multi
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="multiclass",
-        allowed_component_graphs=None,
-        allowed_model_families=[ModelFamily.RANDOM_FOREST],
-    )
-    expected_pipelines = [
-        make_pipeline(X, y, estimator, ProblemTypes.MULTICLASS)
-        for estimator in get_estimators(
-            ProblemTypes.MULTICLASS, model_families=[ModelFamily.RANDOM_FOREST]
-        )
-    ]
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-
-    env = AutoMLTestEnv("multiclass")
-    with env.test_context(score_return_value={automl.objective.name: 1}):
-        automl.search()
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="multiclass",
-        allowed_component_graphs=None,
-        allowed_model_families=["random_forest"],
-    )
-    expected_pipelines = [
-        make_pipeline(X, y, estimator, ProblemTypes.MULTICLASS)
-        for estimator in get_estimators(
-            ProblemTypes.MULTICLASS, model_families=[ModelFamily.RANDOM_FOREST]
-        )
-    ]
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    with env.test_context(score_return_value={automl.objective.name: 1}):
-        automl.search()
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    assert set(automl.allowed_model_families) == set([ModelFamily.RANDOM_FOREST])
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-
-def test_automl_component_graphs_init_allowed_both_not_specified_binary(
-    AutoMLTestEnv, X_y_binary, assert_allowed_pipelines_equal_helper
-):
-    X, y = X_y_binary
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="binary",
-        allowed_component_graphs=None,
-        allowed_model_families=None,
-        optimize_thresholds=False,
-    )
-    expected_pipelines = [
-        make_pipeline(X, y, estimator, ProblemTypes.BINARY)
-        for estimator in get_estimators(ProblemTypes.BINARY, model_families=None)
-    ]
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    env = AutoMLTestEnv("binary")
-    with env.test_context(score_return_value={automl.objective.name: 1}):
-        automl.search()
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    assert set(automl.allowed_model_families) == set(
-        [p.model_family for p in expected_pipelines]
-    )
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-
-def test_automl_component_graphs_init_allowed_both_not_specified_multi(
-    AutoMLTestEnv, X_y_multi, assert_allowed_pipelines_equal_helper
-):
-    X, y = X_y_multi
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="multiclass",
-        allowed_component_graphs=None,
-        allowed_model_families=None,
-    )
-    expected_pipelines = [
-        make_pipeline(X, y, estimator, ProblemTypes.MULTICLASS)
-        for estimator in get_estimators(ProblemTypes.MULTICLASS, model_families=None)
-    ]
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    env = AutoMLTestEnv("multiclass")
-    with env.test_context(score_return_value={automl.objective.name: 1}):
-        automl.search()
-    assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
-    assert set(automl.allowed_model_families) == set(
-        [p.model_family for p in expected_pipelines]
-    )
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-
-def test_automl_component_graphs_init_allowed_both_specified_binary(
-    AutoMLTestEnv,
-    dummy_classifier_estimator_class,
-    dummy_binary_pipeline,
-    X_y_binary,
-):
-    X, y = X_y_binary
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="binary",
-        allowed_component_graphs={
-            "Mock Binary Classification Pipeline": [dummy_classifier_estimator_class]
-        },
-        allowed_model_families=[ModelFamily.RANDOM_FOREST],
-        optimize_thresholds=False,
-    )
-    expected_component_graph = dummy_binary_pipeline.component_graph
-    expected_name = dummy_binary_pipeline.name
-    expected_parameters = dummy_binary_pipeline.parameters
-    assert automl.allowed_pipelines[0].component_graph == expected_component_graph
-    assert automl.allowed_pipelines[0].name == expected_name
-    assert automl.allowed_pipelines[0].parameters == expected_parameters
-    assert automl.allowed_model_families == [ModelFamily.NONE]
-
-    env = AutoMLTestEnv("binary")
-    with env.test_context(score_return_value={automl.objective.name: 1}):
-        automl.search()
-    assert set(automl.allowed_model_families) == set(
-        [p.model_family for p in [dummy_binary_pipeline]]
-    )
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-
-def test_automl_component_graphs_init_allowed_both_specified_multi(
-    AutoMLTestEnv,
-    dummy_classifier_estimator_class,
-    dummy_multiclass_pipeline,
-    X_y_multi,
-):
-    X, y = X_y_multi
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        problem_type="multiclass",
-        allowed_component_graphs={
-            "Mock Multiclass Classification Pipeline": [
-                dummy_classifier_estimator_class
-            ]
-        },
-        allowed_model_families=[ModelFamily.RANDOM_FOREST],
-    )
-    expected_component_graph = dummy_multiclass_pipeline.component_graph
-    expected_name = dummy_multiclass_pipeline.name
-    expected_parameters = dummy_multiclass_pipeline.parameters
-    assert automl.allowed_pipelines[0].component_graph == expected_component_graph
-    assert automl.allowed_pipelines[0].name == expected_name
-    assert automl.allowed_pipelines[0].parameters == expected_parameters
-    assert automl.allowed_model_families == [ModelFamily.NONE]
-
-    env = AutoMLTestEnv("multiclass")
-    with env.test_context(score_return_value={automl.objective.name: 1}):
-        automl.search()
-    assert set(automl.allowed_model_families) == set(
-        [p.model_family for p in [dummy_multiclass_pipeline]]
-    )
-    env.mock_fit.assert_called()
-    env.mock_score.assert_called()
-
-
-@pytest.mark.parametrize("problem_type", ["binary", "multiclass"])
-def test_automl_component_graphs_search(
-    problem_type,
-    example_graph,
-    X_y_binary,
-    X_y_multi,
-    AutoMLTestEnv,
-):
-    if problem_type == "binary":
-        X, y = X_y_binary
-        score_return_value = {"Log Loss Binary": 1.0}
-        expected_mock_class = BinaryClassificationPipeline
-    else:
-        X, y = X_y_multi
-        score_return_value = {"Log Loss Multiclass": 1.0}
-        expected_mock_class = MulticlassClassificationPipeline
-    component_graph = {"CG": example_graph}
-
-    start_iteration_callback = MagicMock()
-    automl = AutoMLSearch(
-        X_train=X,
-        y_train=y,
-        max_iterations=5,
-        problem_type=problem_type,
-        start_iteration_callback=start_iteration_callback,
-        allowed_component_graphs=component_graph,
-        optimize_thresholds=False,
-    )
-    env = AutoMLTestEnv(problem_type)
-    with env.test_context(score_return_value=score_return_value):
-        automl.search()
-
-    assert isinstance(
-        start_iteration_callback.call_args_list[0][0][0], expected_mock_class
-    )
-    for i in range(1, 5):
-        if problem_type == "binary":
-            assert isinstance(
-                start_iteration_callback.call_args_list[i][0][0],
-                BinaryClassificationPipeline,
-            )
-        elif problem_type == "multiclass":
-            assert isinstance(
-                start_iteration_callback.call_args_list[i][0][0],
-                MulticlassClassificationPipeline,
-            )
-
-
 @pytest.mark.parametrize(
     "problem_type",
     [ProblemTypes.TIME_SERIES_MULTICLASS, ProblemTypes.TIME_SERIES_BINARY],
@@ -1235,6 +865,7 @@ def test_automl_search_sampler_ratio(
         problem_type=problem_type,
         sampler_method="auto",
         sampler_balanced_ratio=sampling_ratio,
+        automl_algorithm="iterative",
     )
     pipelines = automl.allowed_pipelines
     if sampling_ratio <= 0.2:
@@ -1259,33 +890,6 @@ def test_automl_search_sampler_ratio(
                 assert comp.parameters["sampling_ratio"] == sampling_ratio
 
 
-def test_automl_oversampler_selection():
-    X = pd.DataFrame({"a": ["a"] * 50 + ["b"] * 25 + ["c"] * 25, "b": list(range(100))})
-    y = pd.Series([1] * 90 + [0] * 10)
-    X.ww.init(logical_types={"a": "Categorical"})
-
-    sampler = get_best_sampler_for_data(
-        X, y, sampler_method="Oversampler", sampler_balanced_ratio=0.5
-    )
-
-    allowed_component_graph = {
-        "DropCols": ["Drop Columns Transformer", "X", "y"],
-        "Oversampler": [sampler, "DropCols.x", "y"],
-        "RF": ["Random Forest Classifier", "Oversampler.x", "Oversampler.y"],
-    }
-
-    automl = AutoMLSearch(
-        X,
-        y,
-        "binary",
-        allowed_component_graphs={"pipeline": allowed_component_graph},
-        pipeline_parameters={"DropCols": {"columns": ["a"]}},
-        error_callback=raise_error_callback,
-    )
-    # This should run without error
-    automl.search()
-
-
 @pytest.mark.parametrize("problem_type", ["binary", "multiclass"])
 @pytest.mark.parametrize(
     "sampler_method,categorical_features",
@@ -1312,7 +916,11 @@ def test_automl_search_sampler_method(
     # 0.2 minority:majority class ratios
     X, y = mock_imbalanced_data_X_y(problem_type, categorical_features, "small")
     automl = AutoMLSearch(
-        X_train=X, y_train=y, problem_type=problem_type, sampler_method=sampler_method
+        X_train=X,
+        y_train=y,
+        problem_type=problem_type,
+        sampler_method=sampler_method,
+        automl_algorithm="iterative",
     )
     # since our default sampler_balanced_ratio for AutoMLSearch is 0.25, we should be adding the samplers when we can
     pipelines = automl.allowed_pipelines
@@ -1398,6 +1006,7 @@ def test_automl_search_dictionary_undersampler(
         optimize_thresholds=False,
         sampler_method="Undersampler",
         pipeline_parameters=pipeline_parameters,
+        max_batches=3,
     )
     # check that the sampling dict got set properly
     automl.search()
@@ -1453,6 +1062,7 @@ def test_automl_search_dictionary_oversampler(
         sampler_method="Oversampler",
         optimize_thresholds=False,
         pipeline_parameters=pipeline_parameters,
+        max_batches=3,
     )
     # check that the sampling dict got set properly
     pipelines = automl.allowed_pipelines
@@ -1500,6 +1110,7 @@ def test_automl_search_sampler_dictionary_keys(
         sampler_method=sampler,
         optimize_thresholds=False,
         pipeline_parameters=pipeline_parameters,
+        max_batches=3,
     )
     if errors:
         with pytest.raises(
@@ -1597,17 +1208,19 @@ def test_time_series_pipeline_parameter_warnings(
             X_train=X,
             y_train=y,
             problem_type="time series binary",
-            max_batches=2,
+            max_batches=1,
             n_jobs=1,
             pipeline_parameters=pipeline_parameters,
             problem_configuration=configuration,
+            automl_algorithm="iterative",
         )
         env = AutoMLTestEnv("time series binary")
         with env.test_context(score_return_value={automl.objective.name: 1.0}):
             automl.search()
+
     # We throw a warning about time series being in beta
-    assert len(w) == (2 if len(set_values) else 1)
-    if len(w) == 2:
+    assert w[0].category == UserWarning
+    if len(w) > 1:
         assert w[1].message.components == set_values
 
 
@@ -1640,12 +1253,12 @@ def test_automl_passes_allow_long_running_models(
         y_train=y,
         problem_type="multiclass",
         allow_long_running_models=allow_long_running_models,
-        _automl_algorithm=algo,
+        automl_algorithm=algo,
         max_batches=2,
         verbose=True,
     )
     assert (
-        automl._automl_algorithm.allow_long_running_models == allow_long_running_models
+        automl.automl_algorithm.allow_long_running_models == allow_long_running_models
     )
     if algo == "default":
         automl.search()
