@@ -104,9 +104,8 @@ def test_polynomial_detrender_needs_monotonic_index(ts_data):
         y_shuffled = y.sample(frac=1, replace=False)
         detrender.fit_transform(X, y_shuffled)
     assert "monotonically" in str(exec_info.value)
-
     with pytest.raises(
-        NotImplementedError,
+        Exception,
         match="class 'pandas.core.indexes.base.Index'> is not supported",
     ):
         y_string_index = pd.Series(np.arange(31), index=[f"row_{i}" for i in range(31)])
