@@ -15,6 +15,7 @@ from evalml.pipelines.components import ComponentBase, RandomForestClassifier
 from evalml.pipelines.components.utils import (
     _all_estimators,
     all_components,
+    estimator_unable_to_handle_nans,
     handle_component_class,
     make_balancing_dictionary,
     scikit_learn_wrapped_estimator,
@@ -37,6 +38,7 @@ minimum_dependencies_set = set(
         "Drop Columns Transformer",
         "Drop Null Columns Transformer",
         "Drop Rows Transformer",
+        "Drop NaN Rows Transformer",
         "Elastic Net Classifier",
         "Elastic Net Regressor",
         "Email Featurizer",
@@ -252,3 +254,14 @@ def test_make_balancing_dictionary_errors():
 def test_make_balancing_dictionary(y, sampling_ratio, result):
     dic = make_balancing_dictionary(y, sampling_ratio)
     assert dic == result
+
+
+def test_estimator_unable_to_handle_nans():
+    test_estimator = RandomForestClassifier()
+    assert estimator_unable_to_handle_nans(test_estimator) is True
+
+    with pytest.raises(
+        ValueError,
+        match="`estimator_class` must have a `model_family` attribute.",
+    ):
+        estimator_unable_to_handle_nans("error")
